@@ -9,6 +9,7 @@ from io import StringIO
 from random import randint
 from time import time, localtime
 
+import email
 from email.message import Message
 from email.utils import formatdate
 
@@ -420,7 +421,7 @@ class ExceptionHandler:
         filename = os.path.join(
             self._app._errorMessagesDir, self.errorPageFilename())
         try:
-            with open(filename, 'w') as f:
+            with open(filename, 'w', encoding='utf-8') as f:
                 f.write(html)
         except IOError:
             sys.stderr.write(
@@ -472,10 +473,10 @@ class ExceptionHandler:
         filename = self._app.setting('ErrorLogFilename')
         try:
             if os.path.exists(filename):
-                with open(filename, 'a') as f:
+                with open(filename, 'a', encoding='utf-8') as f:
                     f.write(logLine)
             else:
-                with open(filename, 'w') as f:
+                with open(filename, 'w', encoding='utf-8') as f:
                     f.write(
                         'time,filename,pathname,exception name,'
                         'exception data,error report filename\n')
@@ -489,6 +490,13 @@ class ExceptionHandler:
         Send the exception via mail, either as an attachment,
         or as the body of the mail.
         """
+
+        # We use quoted-printable encoding, which will automatically split
+        # long lines. This is important because tracebacks can contain long
+        # representations of Python data, longer than the maximum line length
+        # that SMTP servers will accept (a typical limit is 990 bytes).
+        charset = email.charset.Charset('utf-8')
+        charset.body_encoding = email.charset.QP
         message = Message()
 
         # Construct the message headers
@@ -519,7 +527,6 @@ class ExceptionHandler:
             message.attach(part)
             part = Message()
             # now add htmlErrMsg
-            part.add_header('Content-Transfer-Encoding', '7bit')
             part.add_header(
                 'Content-Description',
                 'HTML version of Webware error message')
@@ -527,11 +534,11 @@ class ExceptionHandler:
                 'Content-Disposition',
                 'attachment', filename='WebwareErrorMsg.html')
             part.set_type('text/html')
-            part.set_payload(htmlErrMsg)
+            part.set_payload(htmlErrMsg, charset=charset)
             message.attach(part)
         else:
             message.set_type('text/html')
-            message.set_payload(htmlErrMsg, 'us-ascii')
+            message.set_payload(htmlErrMsg, charset=charset)
 
         # Send the message
         server = self.setting('ErrorEmailServer')
