@@ -197,7 +197,8 @@ class ContextParser(URLParser):
                             print("Creating __init__.py file"
                                   f" for context {name!r}")
                             try:
-                                with open(initPy, 'w') as initPyFile:
+                                with open(initPy, 'w',
+                                          encoding='ascii') as initPyFile:
                                     initPyFile.write(
                                         '# Auto-generated by Webware' +
                                         os.linesep)
